@@ -5,6 +5,8 @@ from . import libswn as swn
 from .workday import *
 from .database import *
 from .msgc import *
+from .utils import *
+from .sendemail import *
 
 import datetime,time,inspect,collections,hashlib,base64,urllib.request,json,subprocess
 import os,re,shutil,smtplib,sys,getpass
@@ -367,31 +369,6 @@ def sjbj(sjhm,nr,td="AB"):  #手机报警
     for hm in sjhm:
         cc.jg1("select smsalert(:hm,:nr,4,:td) from dual",hm=hm,nr=nr,td=td)
 
-class c_xx(object):   #消息处理
-    def __init__(self):
-        self.cc=c_oracle("xtjk@cc",yslj=True)
-    def dwx(self,组,消息内容,标题=None,消息保存天数=30):
-        self.dx(组,消息内容,标题,消息保存天数)
-        self.wx(组,消息内容,标题,消息保存天数)
-    def dx(self,组,消息内容,标题=None,消息保存天数=30):
-        s=sys._getframe(1)
-        标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
-        self.cc.execute("select f_dx(:z,:xxnr,:bt,:ts) from dual",z=组,xxnr=消息内容,bt=标题,ts=消息保存天数)
-    def gzt(self,组,消息标识,消息内容,标题=None,消息保存天数=30): #工作台消息
-        s=sys._getframe(1)
-        标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
-        if 消息内容=="":消息内容="正常"
-        self.cc.execute("select f_gzt(:z,:xxnr,:bt,:ts) from dual",z=组,xxnr="%s|1|%s" %(消息标识,消息内容),bt=标题,ts=消息保存天数)
-    def wx(self,组,消息内容,标题=None,消息保存天数=30):
-        s=sys._getframe(1)
-        标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
-        self.cc.execute("select f_wx(:z,:xxnr,:bt,:ts) from dual",z=组,xxnr=消息内容,bt=标题,ts=消息保存天数)
-    def mail(self,组,消息内容,标题=None,消息保存天数=30):
-        s=sys._getframe(1)
-        标题=标题 or "%s:%d" %(s.f_code.co_filename.split("/")[-1] , s.f_lineno)
-        消息内容=消息内容.replace("\n","<br>")
-        self.cc.execute("select f_text_email('rtta@rtfund.com',:z,:bt,:xxnr,:ts) from dual",z=组,xxnr=消息内容,bt=标题,ts=消息保存天数)
-
 def swexit(returncode,msg="",nextchecktime=""): #事务退出环节
     global swrq
     if swid==0: #事务id为0是测试，不用写退出环节
