@@ -1,27 +1,27 @@
 #!/usr/bin/python3
 # -*- coding: utf8 -*-
 
-__all__=["c_oracle","c_database"]
+__all__=["c_oracle","c_database","c_mssql","c_tds","c_mysql"]
 
 import time,base64,sys,json,urllib.request,ssl,os,datetime
 import libsw3 as sw3
 
 class c_database(object):
-    def __init__(self,sconn=""):
-        self.sconn=sconn
+    def __init__(self,*连接参数1,**连接参数2):
+        self.连接参数1=连接参数1
+        self.连接参数2=连接参数2
         self.connected=False
+    def commit(self):
+        self.conn.commit()
     def convconn(self,ljc):
         if ljc.find("/")>0 or ljc.find("}")>0:
             return ljc
         dh,_=os.path.splitdrive(os.getcwd())
-        fn1=os.path.join(dh,"/etc","dbconn.cfg")
         fn2=os.path.join(dh,"/etc","oraconn.cfg")
-        if os.path.isfile(fn1):
-            f=open(fn1)
-        elif os.path.isfile(fn2):
+        if os.path.isfile(fn2):
             f=open(fn2)
         else:
-            sw3.swexit(-1,"无法打开连接串配置文件%s或者%s" %(fn1,fn2))
+            sw3.swexit(-1,"无法打开连接串配置文件%s" %(fn2))
         wjnr=f.readlines()
         f.close()
         for i in wjnr:
@@ -31,10 +31,123 @@ class c_database(object):
             if s[0]==ljc:
                 return s[1]
         return ""
+    def 解析连接参数(self):
+        self.sconn=""
+        if len(self.连接参数1)>0:
+            self.sconn=self.连接参数1[0]
+            dh,_=os.path.splitdrive(os.getcwd())
+            配置文件=os.path.join(dh,"/etc","dbconn.config.d","%s.cfg" %(self.sconn))
+            if os.path.isfile(配置文件):
+                配置数据=json.loads(open(配置文件).read())
+                for i in 配置数据:
+                    if i["db"]==self.name:
+                        self.连接参数1=i["t"]
+                        self.连接参数2=i["d"]
+    def connect(self,*args,**kwargs):
+        self.connected=True
+        if len(args)>0 or len(kwargs)>0:
+            self.连接参数1=args
+            self.连接参数2=kwargs
+        self.解析连接参数()
+        try:
+            self.conn=self.dbdriver.connect(*self.连接参数1,**self.连接参数2)
+        except:
+            sw3.swexit(1,"数据库连接%s不成功" %(self.sconn))
+        else:
+            self.c=self.conn.cursor()
+    def execute(self,ssql,*args,**kwargs):
+        c=self.conn.cursor()
+        c.execute(ssql,*args,**kwargs)
+        return c
+    def jg1(self,ssql,*args,**kwargs):
+        '''根据sql返回1条结果'''
+        c=self.conn.cursor()
+        c.execute(ssql,*args,**kwargs)
+        jg=c.fetchone()
+        c.close()
+        if jg==None:
+            return
+        if len(jg)==1:
+            return jg[0]
+        else:
+            return jg
+    def __getattribute__(self,name):
+        if name in ("c","conn") and not self.connected:
+            self.connected=True
+            self.connect()
+        return object.__getattribute__(self,name)
 
 class c_mysql(c_database):
-    def __init__(self,sconn=""):
-        pass
+    import pymysql
+    dbdriver=pymysql
+    name="mysql"
+
+class c_tds(c_database):
+    import pytds
+    dbdriver=pytds
+    name="tds"
+
+class c_mssql():
+    def __init__(self,sconn="",yslj=False,autocommit=False,raiseExp=True):
+        global pymssql, configparser
+        import pymssql, configparser
+        self.sconn = sconn
+        self.connected = False
+        self.autocommit = autocommit
+        self.raiseExp = raiseExp
+        self.host,self.user,self.password,self.database = ('','','','')
+        (not yslj) and self.connect()
+
+    def convconn(self):
+        if os.path.isfile("/etc/mssqlconn.cfg"):
+            cfg = configparser.ConfigParser()
+            cfg.read("/etc/mssqlconn.cfg")
+            self.host = cfg.get(self.sconn,'host')
+            self.user = cfg.get(self.sconn,'user')
+            self.password = cfg.get(self.sconn,'password')
+            self.database = cfg.get(self.sconn,'database')
+
+    def connect(self, sconn=""):
+        if sconn != "":
+            self.sconn = sconn
+            self.connected = False
+        if self.connected:
+            c = self.conn.cursor()
+            try:
+                c.execute("select 1")
+            except Exception as e:
+                self.connected = False
+                print("SqlServer连接数据库异常：%s" % (e))
+                if self.raiseExp:
+                    raise  # 往上层抛
+            else:
+                return
+        try:
+            self.convconn()
+            print(self.host,self.user,self.password,self.database)
+            self.conn = pymssql.connect(host=self.host,user=self.user,password=self.password,database=self.database)
+        except Exception as e:
+            sw3.swexit(1, "SqlServer数据库连接%s不成功" % (self.sconn))
+            error, = e.args
+            if self.raiseExp:
+                raise  # 往上层抛
+        else:
+            self.connected = True
+
+    def execute(self,ssql,*args,**kwargs):
+        (not self.connected) and self.connect()
+        if not self.connected:
+            return
+        try:
+            c=self.conn.cursor()
+            c.execute(ssql,*args,**kwargs)
+        except Exception as e:
+            self.connected=False
+            print("SqlServer执行异常：%s" % (e))
+            if self.raiseExp:
+                raise  # 往上层抛
+            return
+        return c
 
 class c_oracle(c_database):
     def __init__(self,sconn="",yslj=False,autocommit=False,raiseExp=True):
